fn compute_merged_options(
current_options: &str,
source_options: &BTreeMap<String, CmdlineOwned>,
target_source: &SourceName,
new_options: Option<&str>,
) -> CmdlineOwnedExpand description
Compute the merged options line from all sources.
The algorithm:
- Start with the current options line
- Remove all options that belong to the old value of the specified source
- Add the new options for the specified source
Options not tracked by any source are preserved as-is.